@@ -5,18 +5,18 @@ from bs4 import BeautifulSoup
 import json
 
 baseURL = "https://nn3.freenet.de/clevertanken/main.php?cm=1"
-#baseURL = "http://130.61.217.10/main.php?cm=1"
-autogas = "Autogas"
-diesel = "Diesel"
-erdgas = "Erdgas"
-superplus = "SuperPlus"
-super = "Super"
-normal = "Normal"
-FUEL = [autogas, diesel, erdgas, superplus, super, normal]
+debugbaseURL = "http://130.61.217.10/main.php?cm=1"
+_autogas = "Autogas"
+_diesel = "Diesel"
+_erdgas = "Erdgas"
+_superplus = "SuperPlus"
+_super = "Super"
+_normal = "Normal"
+FUEL = [_autogas, _diesel, _erdgas, _superplus, _super, _normal]
 
 class ITBObject:
     def __init__(self):
-        self.version = "1.0.21"
+        self.version = "1.0.24"
         self.author = "Ludy87"
         self.project = "Py Ich tanke billig"
         self.page = "https://www.astra-g.org/"
@@ -44,7 +44,7 @@ def connenctionLib(url):
         response = request.urlopen(req)
         return response.read()
 
-def getStations(kraftstoff = diesel, place = '123', limit = '-1', asJson = False):
+def getStations(kraftstoff = _diesel, place = '123', limit = '-1', asJson = False):
     url = baseURL + '&sprit=' + kraftstoff + '&ort=' + urllib.parse.quote(str(place))
     data = connenctionLib(url)
     text = data.decode('utf-8')
@@ -200,6 +200,7 @@ def getStationsA(kraftstoffe = FUEL, place_plz = '123', limit = '-1', asJson = F
 
 def getStationsB(kraftstoffe = FUEL, place_plz = '123', limit = -1, asJson = False):
     stations = {}
+    stations['fuel_type'] = kraftstoffe
     for kraftstoff in kraftstoffe:
         me = ITBObject()
         url = baseURL + '&sprit=' + kraftstoff + '&ort=' + urllib.parse.quote(place_plz)
@@ -230,6 +231,7 @@ def getStationsB(kraftstoffe = FUEL, place_plz = '123', limit = -1, asJson = Fal
                 colErg1_a = colErg1.getText().strip().split('<br>')[0].split('\n')
                 if len(colErg1_a) < 3:
                     me.status = {"error": 403}
+                    stations['error'] = 403
                 else:
                     stationName = colErg1_a[0].strip()
                     street = colErg1_a[1].strip()
@@ -254,7 +256,76 @@ def getStationsB(kraftstoffe = FUEL, place_plz = '123', limit = -1, asJson = Fal
                         "fuel": kraftstoff,
                         "pos": i +1,
                     }
-                    if limit == i and limit != -1:
+                    if limit == str(i) and limit != '-1':
+                        break
+                    i += 1
+                    stations[kraftstoff].append(json_data)
+    if asJson:
+        return toJSON(stations)
+    return (stations)
+
+def getStationsC(kraftstoffe = FUEL, place_plz = '123', limit = -1, asJson = False, debug = False):
+    stations = {}
+    stations['fuel_type'] = kraftstoffe
+    for kraftstoff in kraftstoffe:
+        me = ITBObject()
+        if debug:
+            url = debugbaseURL + '&sprit=' + kraftstoff + '&ort=' + urllib.parse.quote(place_plz)
+        else:
+            url = baseURL + '&sprit=' + kraftstoff + '&ort=' + urllib.parse.quote(place_plz)
+        data = connenctionLib(url)
+        text = data.decode('utf-8')
+        bs = BeautifulSoup(text, 'html.parser')
+        rows = bs.find_all('tr')
+        if len(rows) == 0:
+            info_msg = bs.find('div', {"class": "frn_contHead"})
+            if info_msg != None:
+                stations["error"] = info_msg.getText()
+            else:
+                stations["error"] = bs.getText().strip()
+        else:
+            stations['status'] = 200
+            stations[kraftstoff] = []
+
+            i = 0
+            for row in rows:
+                if not row.text.strip():
+                    continue
+                if not row.find('td'):
+                    continue
+                colErg1 = row.find('td', {"class": "colErg1"})
+                colErg2 = row.find('td', {"class": "colErg2"})
+                colErg3 = row.find('td', {"class": "colErg3"})
+
+                colErg1_a = colErg1.getText().strip().split('<br>')[0].split('\n')
+                if len(colErg1_a) < 3:
+                    me.status = {"error": 403}
+                    stations['error'] = 403
+                else:
+                    stationName = colErg1_a[0].strip()
+                    street = colErg1_a[1].strip()
+                    place = colErg1_a[2].strip()
+                    plz = place.split()[0]
+                    ort = place.split()[1]
+
+                    price = colErg2.getText().strip()
+
+                    reloaded = colErg3.getText().strip().split('<br>')[0].split('\n')
+                    reloaded = reloaded[1].strip() + " " + reloaded[0].strip()
+                    sum = stationName + street + place
+                    sum = hashlib.md5(sum.encode()).hexdigest()
+                    json_data = {
+                        "id": sum,
+                        "station_name": stationName,
+                        "street": street,
+                        "place": ort,
+                        "plz": plz,
+                        "price": price,
+                        "reloaded": reloaded,
+                        "fuel": kraftstoff,
+                        "pos": i +1,
+                    }
+                    if limit == str(i) and limit != '-1':
                         break
                     i += 1
                     stations[kraftstoff].append(json_data)
